changeset 2635:99c6d0cea264

More creator -> author renames.
author Matti Hamalainen <ccr@tnsp.org>
date Sun, 18 Feb 2024 05:33:35 +0200
parents ab7531b2d170
children 27a54505e586
files src/liblocfile.c src/liblocfile.h src/mkloc.c
diffstat 3 files changed, 11 insertions(+), 11 deletions(-) [+]
line wrap: on
line diff
--- a/src/liblocfile.c	Sun Feb 18 05:25:26 2024 +0200
+++ b/src/liblocfile.c	Sun Feb 18 05:33:35 2024 +0200
@@ -52,7 +52,7 @@
 }
 
 
-const char * locGetAreaCreatorRole(const int flags, const bool type)
+const char * locGetAreaAuthorRole(const int flags, const bool type)
 {
     const char *pfx;
     const char *desc;
@@ -70,7 +70,7 @@
 }
 
 
-static void locAddAreaCreator(LocName *dst, int *ndst, const LocName *src, const int nsrc)
+static void locAddAreaAuthor(LocName *dst, int *ndst, const LocName *src, const int nsrc)
 {
     if (src != NULL && src[nsrc].name != NULL)
     {
@@ -194,7 +194,7 @@
     for (i = 0; i < LOC_MAX_NAMES; i++)
     {
         locAddAreaName(tmp->names, &tmp->nnames, names, i);
-        locAddAreaCreator(tmp->authors, &tmp->nauthors, authors, i);
+        locAddAreaAuthor(tmp->authors, &tmp->nauthors, authors, i);
     }
 
     if (added != NULL)
@@ -591,7 +591,7 @@
         locParseMultiField(ctx, "|;", '|', "location names", marker->names);
         break;
 
-    case 5:            // Creators
+    case 5:            // Authors
         locParseMultiField(ctx, ",;", ',', "author names", marker->authors);
         break;
 
--- a/src/liblocfile.h	Sun Feb 18 05:25:26 2024 +0200
+++ b/src/liblocfile.h	Sun Feb 18 05:33:35 2024 +0200
@@ -78,7 +78,7 @@
 #define LOC_MAX_FILES          (64)
 
 
-/* Creator roles
+/* Author roles
  */
 #define AUTHOR_ORIG            (0x00001)   // '@' Original area author
 #define AUTHOR_RECODER         (0x00002)   // '!' Converter or recoder of area
@@ -156,7 +156,7 @@
 /* Location file parsing and data handling
  */
 const char * locGetAreaNameType(const int flags, const bool type);
-const char * locGetAreaCreatorRole(const int flags, const bool type);
+const char * locGetAreaAuthorRole(const int flags, const bool type);
 const char * locGetTypePrefix(const int flags);
 const char * locGetTypeName(const int flags);
 
--- a/src/mkloc.c	Sun Feb 18 05:25:26 2024 +0200
+++ b/src/mkloc.c	Sun Feb 18 05:33:35 2024 +0200
@@ -667,7 +667,7 @@
  */
 void printLocNameEsc(FILE *outFile, const LocName *name)
 {
-    fputs(locGetAreaCreatorRole(name->flags, false), outFile);
+    fputs(locGetAreaAuthorRole(name->flags, false), outFile);
     fputsesc2(name->name, outFile);
 }
 
@@ -1006,7 +1006,7 @@
             loc->added.day, loc->added.month, loc->added.year);
     }
 
     // Creator names or societies
     if (loc->nauthors > 0)
     {
         if (loc->flags & LOCF_M_PCITY)
@@ -1021,7 +1021,7 @@
         }
         else
         {
-            fprintf(outFile, "Creators: ");
+            fprintf(outFile, "Authors: ");
             for (int n = 0; n < loc->nauthors; n++)
             {
                 char *info = "", *sinfo = "";
@@ -1162,7 +1162,7 @@
             fprintf(outFile, "</altnames>");
         }
 
-        // Creators or secret societies
+        // Authors or secret societies
         if (loc->nauthors > 0)
         {
             if (loc->flags & LOCF_M_PCITY)
@@ -1182,7 +1182,7 @@
                 for (int n = 0; n < loc->nauthors; n++)
                 {
                     fprintf(outFile, "<author role=\"%s\">",
-                        locGetAreaCreatorRole(loc->authors[n].flags, true));
+                        locGetAreaAuthorRole(loc->authors[n].flags, true));
                     fputse(loc->authors[n].name, outFile);
                     fprintf(outFile, "</author>");
                 }
@@ -1006,7 +1006,7 @@
     }
 
-    // Creator names or societies
+    // Author names or societies
     if (loc->nauthors > 0)
     {